@@ -505,7 +505,7 @@ where
                                         key = attr
                                             .value
                                             .and_then(jsx_attr_value_to_expr)
-                                            .map(|expr| ExprOrSpread { expr, spread: None });
+                                            .map(|expr| expr.as_arg());
                                         assert_ne!(
                                             key, None,
                                             "value of property 'key' should not be empty"
@@ -523,7 +523,7 @@ where
                                         source_props = attr
                                             .value
                                             .and_then(jsx_attr_value_to_expr)
-                                            .map(|expr| ExprOrSpread { expr, spread: None });
+                                            .map(|expr| expr.as_arg());
                                         assert_ne!(
                                             source_props, None,
                                             "value of property '__source' should not be empty"
@@ -541,7 +541,7 @@ where
                                         self_props = attr
                                             .value
                                             .and_then(jsx_attr_value_to_expr)
-                                            .map(|expr| ExprOrSpread { expr, spread: None });
+                                            .map(|expr| expr.as_arg());
                                         assert_ne!(
                                             self_props, None,
                                             "value of property '__self' should not be empty"
@@ -663,28 +663,19 @@ where
                     // set undefined literal to key if key is None
                     let key = match key {
                         Some(key) => key,
-                        None => ExprOrSpread {
-                            spread: None,
-                            expr: undefined(DUMMY_SP),
-                        },
+                        None => undefined(DUMMY_SP).as_arg(),
                     };
 
                     // set undefined literal to __source if __source is None
                     let source_props = match source_props {
                         Some(source_props) => source_props,
-                        None => ExprOrSpread {
-                            spread: None,
-                            expr: undefined(DUMMY_SP),
-                        },
+                        None => undefined(DUMMY_SP).as_arg(),
                     };
 
                     // set undefined literal to __self if __self is None
                     let self_props = match self_props {
                         Some(self_props) => self_props,
-                        None => ExprOrSpread {
-                            spread: None,
-                            expr: undefined(DUMMY_SP),
-                        },
+                        None => undefined(DUMMY_SP).as_arg(),
                     };
                     args.chain(once(key))
                         .chain(once(
